==> script-security-1.18-sources.jar: org/jenkinsci/plugins/scriptsecurity/scripts/Messages.java <==
// CHECKSTYLE:OFF

package org.jenkinsci.plugins.scriptsecurity.scripts;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;


/**
 * Generated localization support class.
 * 
 */
@SuppressWarnings({
    "",
    "PMD",
    "all"
})
public class Messages {

    /**
     * The resource bundle reference
     * 
     */
    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     * Key {@code ClasspathEntry.path.notExists}: {@code Specified path does
     * not exist}.
     * 
     * @return
     *     {@code Specified path does not exist}
     */
    public static String ClasspathEntry_path_notExists() {
        return holder.format("ClasspathEntry.path.notExists");
    }

    /**
     * Key {@code ClasspathEntry.path.notExists}: {@code Specified path does
     * not exist}.
     * 
     * @return
     *     {@code Specified path does not exist}
     */
    public static Localizable _ClasspathEntry_path_notExists() {
        return new Localizable(holder, "ClasspathEntry.path.notExists");
    }

    /**
     * Key {@code ClasspathEntry.path.notApproved}: {@code This classpath
     * entry is not approved. Require an approval before execution.}.
     * 
     * @return
     *     {@code This classpath entry is not approved. Require an approval
     *     before execution.}
     */
    public static String ClasspathEntry_path_notApproved() {
        return holder.format("ClasspathEntry.path.notApproved");
    }

    /**
     * Key {@code ClasspathEntry.path.notApproved}: {@code This classpath
     * entry is not approved. Require an approval before execution.}.
     * 
     * @return
     *     {@code This classpath entry is not approved. Require an approval
     *     before execution.}
     */
    public static Localizable _ClasspathEntry_path_notApproved() {
        return new Localizable(holder, "ClasspathEntry.path.notApproved");
    }

}

==> script-security-1.26-sources.jar: org/jenkinsci/plugins/scriptsecurity/scripts/Messages.java <==
// CHECKSTYLE:OFF

package org.jenkinsci.plugins.scriptsecurity.scripts;

import org.jvnet.localizer.Localizable;
import org.jvnet.localizer.ResourceBundleHolder;


/**
 * Generated localization support class.
 * 
 */
@SuppressWarnings({
    "",
    "PMD",
    "all"
})
public class Messages {

    /**
     * The resource bundle reference
     * 
     */
    private final static ResourceBundleHolder holder = ResourceBundleHolder.get(Messages.class);

    /**
     * Key {@code ClasspathEntry.path.notExists}: {@code Specified path does
     * not exist}.
     * 
     * @return
     *     {@code Specified path does not exist}
     */
    public static String ClasspathEntry_path_notExists() {
        return holder.format("ClasspathEntry.path.notExists");
    }

    /**
     * Key {@code ClasspathEntry.path.notExists}: {@code Specified path does
     * not exist}.
     * 
     * @return
     *     {@code Specified path does not exist}
     */
    public static Localizable _ClasspathEntry_path_notExists() {
        return new Localizable(holder, "ClasspathEntry.path.notExists");
    }

    /**
     * Key {@code ClasspathEntry.path.notApproved}: {@code This classpath
     * entry is not approved. Require an approval before execution.}.
     * 
     * @return
     *     {@code This classpath entry is not approved. Require an approval
     *     before execution.}
     */
    public static String ClasspathEntry_path_notApproved() {
        return holder.format("ClasspathEntry.path.notApproved");
    }

    /**
     * Key {@code ClasspathEntry.path.notApproved}: {@code This classpath
     * entry is not approved. Require an approval before execution.}.
     * 
     * @return
     *     {@code This classpath entry is not approved. Require an approval
     *     before execution.}
     */
    public static Localizable _ClasspathEntry_path_notApproved() {
        return new Localizable(holder, "ClasspathEntry.path.notApproved");
    }

    /**
     * Key {@code ClasspathEntry.path.noDirsAllowed}: {@code Class
     * directories are not allowed as classpath entries.}.
     * 
     * @return
     *     {@code Class directories are not allowed as classpath entries.}
     */
    public static String ClasspathEntry_path_noDirsAllowed() {
        return holder.format("ClasspathEntry.path.noDirsAllowed");
    }

    /**
     * Key {@code ClasspathEntry.path.noDirsAllowed}: {@code Class
     * directories are not allowed as classpath entries.}.
     * 
     * @return
     *     {@code Class directories are not allowed as classpath entries.}
     */
    public static Localizable _ClasspathEntry_path_noDirsAllowed() {
        return new Localizable(holder, "ClasspathEntry.path.noDirsAllowed");
    }

}
